@@ -1,4 +1,5 @@
 from __future__ import annotations
+import datetime
 import re
 from time import sleep
 from functools import wraps
@@ -45,6 +46,7 @@ def ignore_exceptions(
     retry_interval: int = 1,
     return_on_error: Any = None,
     logger: Logger | None = None,
+    raise_final_exception: bool = False,
 ) -> Any:
     """
     Decorator to ignore exceptions with support for retry.
@@ -54,6 +56,7 @@ def ignore_exceptions(
         retry_interval (int): Number of seconds to wait between retries.
         return_on_error (Any): Return value if the underline function throw exception.
         logger (Logger): logger to use, if not passed no logs will be displayed.
+        raise_final_exception (bool): whether to raise the final exception.
 
 
     Returns:
@@ -66,14 +69,15 @@ def ignore_exceptions(
             try:
                 return func(*args, **kwargs)
             except Exception as ex:
-                if retry:
-                    sleep(retry_interval)
-                    for _ in range(0, retry):
-                        try:
-                            return func(*args, **kwargs)
-                        except Exception:
-                            sleep(retry_interval)
-
+                for idx in range(0, retry):
+                    try:
+                        sleep(retry_interval)
+                        return func(*args, **kwargs)
+                    except Exception as retry_ex:
+                        if idx + 1 < retry:
+                            continue
+                        if raise_final_exception:
+                            raise retry_ex
                 if logger:
                     logger.error(f"{func.__name__} error: {ex}")
                 return return_on_error
@@ -81,3 +85,47 @@ def ignore_exceptions(
         return inner
 
     return wrapper
+
+
+def stt(seconds: int) -> str:
+    """
+    Convert seconds to human readable time string.
+
+    Args:
+        seconds (int): seconds to convert
+
+    Returns:
+        str: Human readable time string
+
+    Example:
+        >>> stt(seconds=3600)
+        '1 hour'
+        >>> stt(seconds=3600*24)
+        '1 day'
+        >>> stt((60*60*14+65))
+        '14 hours and 1 minute and 5 seconds'
+    """
+    time_str = ""
+    total_seconds = datetime.timedelta(seconds=seconds)
+    days = total_seconds.days
+    total_time = datetime.datetime.strptime(str(datetime.timedelta(seconds=total_seconds.seconds)), "%H:%M:%S")
+    hour, minute, second = total_time.hour, total_time.minute, total_time.second
+    if days:
+        time_str += f"{days} {'days' if days > 1 else 'day'}"
+
+    if hour:
+        if days:
+            time_str += " and "
+        time_str += f"{hour} {'hours' if hour > 1 else 'hour'}"
+
+    if minute:
+        if hour or days:
+            time_str += " and "
+        time_str += f"{minute} {'minutes' if minute > 1 else 'minute'}"
+
+    if total_time.second:
+        if hour or minute:
+            time_str += " and "
+        time_str += f"{second} {'seconds' if second > 1 else 'second'}"
+
+    return time_str
